# This is a BitKeeper generated patch for the following project:
# Project Name: Linux kernel tree
# This patch format is intended for GNU patch command version 2.5 or higher.
# This patch includes the following deltas:
#	           ChangeSet	1.676.14.16 -> 1.676.14.17
#	      fs/proc/base.c	1.12    -> 1.13   
#	include/asm-i386/ptrace.h	1.2     -> 1.3    
#	          fs/fcntl.c	1.8     -> 1.9    
#	  drivers/char/mem.c	1.17    -> 1.18   
#
# The following is the BitKeeper ChangeSet Log
# --------------------------------------------
# 02/09/27	bjorn_helgaas@hp.com	1.676.14.17
# Prevent large lseek returns from being mistaken as errors.
# --------------------------------------------
#
diff -Nru a/drivers/char/mem.c b/drivers/char/mem.c
--- a/drivers/char/mem.c	Wed Oct  8 09:07:18 2003
+++ b/drivers/char/mem.c	Wed Oct  8 09:07:18 2003
@@ -511,13 +511,15 @@
 	switch (orig) {
 		case 0:
 			file->f_pos = offset;
-			return file->f_pos;
+			break;
 		case 1:
 			file->f_pos += offset;
-			return file->f_pos;
+			break;
 		default:
 			return -EINVAL;
 	}
+	force_successful_syscall_return();
+	return file->f_pos;
 }
 
 static int open_port(struct inode * inode, struct file * filp)
diff -Nru a/fs/fcntl.c b/fs/fcntl.c
--- a/fs/fcntl.c	Wed Oct  8 09:07:18 2003
+++ b/fs/fcntl.c	Wed Oct  8 09:07:18 2003
@@ -293,6 +293,7 @@
 			 * to fix this will be in libc.
 			 */
 			err = filp->f_owner.pid;
+			force_successful_syscall_return();
 			break;
 		case F_SETOWN:
 			lock_kernel();
diff -Nru a/fs/proc/base.c b/fs/proc/base.c
--- a/fs/proc/base.c	Wed Oct  8 09:07:18 2003
+++ b/fs/proc/base.c	Wed Oct  8 09:07:18 2003
@@ -438,7 +438,24 @@
 }
 #endif
 
+static loff_t mem_lseek(struct file * file, loff_t offset, int orig)
+{
+	switch (orig) {
+	      case 0:
+		file->f_pos = offset;
+		break;
+	      case 1:
+		file->f_pos += offset;
+		break;
+	      default:
+		return -EINVAL;
+	}
+	force_successful_syscall_return();
+	return file->f_pos;
+}
+
 static struct file_operations proc_mem_operations = {
+	llseek:		mem_lseek,
 	read:		mem_read,
 	write:		mem_write,
 	open:		mem_open,
diff -Nru a/include/asm-i386/ptrace.h b/include/asm-i386/ptrace.h
--- a/include/asm-i386/ptrace.h	Wed Oct  8 09:07:18 2003
+++ b/include/asm-i386/ptrace.h	Wed Oct  8 09:07:18 2003
@@ -58,6 +58,7 @@
 #define user_mode(regs) ((VM_MASK & (regs)->eflags) || (3 & (regs)->xcs))
 #define instruction_pointer(regs) ((regs)->eip)
 extern void show_regs(struct pt_regs *);
+#define force_successful_syscall_return()	do { } while (0)
 #endif
 
 #endif
